@@ -1,6 +1,5 @@
-# ubuntu_sso - Ubuntu Single Sign On client support for desktop apps
 #
-# Copyright 2009-2012 Canonical Ltd.
+# Copyright 2009-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -28,6 +27,15 @@
 # files in the program, then also delete it here.
 """Ubuntu Single Sign On client code."""
 
+import os
+
+
+# Host URL changing environment variables
+SSO_AUTH_BASE_URL = os.environ.get(
+    'SSO_AUTH_BASE_URL', 'https://login.ubuntu.com')
+SSO_UONE_BASE_URL = os.environ.get(
+    'SSO_UONE_BASE_URL', 'https://one.ubuntu.com')
+
 # DBus constants
 DBUS_BUS_NAME = "com.ubuntu.sso"
 
