@@ -1,9 +1,6 @@
 # -*- coding: utf-8 -*-
-
-# Author: Natalia Bidart <natalia.bidart@canonical.com>
-# Author: Alejandro J. Cura <alecu@canonical.com>
 #
-# Copyright 2010-2012 Canonical Ltd.
+# Copyright 2010-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -42,6 +39,7 @@ import re
 
 from twisted.internet import defer
 
+from ubuntu_sso import SSO_AUTH_BASE_URL
 from ubuntu_sso.logger import setup_logging
 from ubuntu_sso.utils import compat, webclient
 from ubuntu_sso.utils.webclient import restful
@@ -49,7 +47,7 @@ from ubuntu_sso.utils.webclient.common import WebClientError
 
 
 logger = setup_logging("ubuntu_sso.account")
-SERVICE_URL = "https://login.ubuntu.com/api/1.0/"
+SERVICE_URL = "%s/api/1.0/" % SSO_AUTH_BASE_URL
 SSO_STATUS_OK = 'ok'
 SSO_STATUS_ERROR = 'error'
 
