@@ -111,10 +111,13 @@ def try_old_credentials(app_name):
     returnValue(None)
 
 
+Keyring = None
 if sys.platform in ('win32', 'darwin'):
-    from ubuntu_sso.keyring.pykeyring import Keyring
+    from ubuntu_sso.keyring import pykeyring
+    Keyring = pykeyring.Keyring
 else:
-    from ubuntu_sso.keyring.linux import Keyring
+    from ubuntu_sso.keyring import linux as linux_kr
+    Keyring = linux_kr.Keyring
 
 
 class UbuntuOneOAuthKeyring(Keyring):
