@@ -37,11 +37,11 @@ import logging
 import os
 import sys
 
+from dirspec.basedir import xdg_cache_home
+from dirspec.utils import unicode_path
 from functools import wraps
 from logging.handlers import RotatingFileHandler
 
-from ubuntu_sso.xdg_base_directory import unicode_path, xdg_cache_home
-
 LOGFOLDER = os.path.join(xdg_cache_home, 'sso')
 # create log folder if it doesn't exists
 if not os.path.exists(unicode_path(LOGFOLDER)):
