@@ -445,6 +445,10 @@ class UbuntuSSOClient(object):
         self.sso_login = SSOLoginClient().dbus_iface
         self.cred_manager = CredentialsManagementClient().dbus_iface
 
+    def connect(self):
+        """No need to connect DBus proxy objects."""
+        return defer.succeed(None)
+
     def disconnect(self):
         """No need to disconnect DBus proxy objects."""
         return defer.succeed(None)
