@@ -684,7 +684,7 @@ class CredentialsManagementRefCountingTestCase(CredentialsManagementTestCase):
         def in_the_middle():
             """Store the ref_count value."""
             counter.append(self.obj.ref_count)
-            return defer.fail('foo')
+            return defer.fail(SampleException('foo'))
 
         self.patch(self.factory.credentials, 'find_credentials', in_the_middle)
         self.obj.find_credentials(APP_NAME, self.args,
