@@ -34,18 +34,16 @@ from twisted.internet import defer
 
 from ubuntu_sso.networkstate import NetworkFailException
 from ubuntu_sso.networkstate.networkstates import (
-    ONLINE, OFFLINE, UNKNOWN,
-
+    ONLINE, OFFLINE,
     NM_STATE_CONNECTING_LIST,
     NM_STATE_CONNECTED_LIST,
     NM_STATE_DISCONNECTED_LIST,
-    )
+)
 from ubuntu_sso.logger import setup_logging
 logger = setup_logging("ubuntu_sso.networkstate")
 
 NM_DBUS_INTERFACE = "org.freedesktop.NetworkManager"
 NM_DBUS_OBJECTPATH = "/org/freedesktop/NetworkManager"
-DBUS_UNKNOWN_SERVICE = "org.freedesktop.DBus.Error.ServiceUnknown"
 
 
 class NetworkManagerState(object):
@@ -72,16 +70,11 @@ class NetworkManagerState(object):
 
     def got_error(self, error):
         """Called by DBus when the state is retrieved from NM."""
-        if isinstance(error, self.dbus.exceptions.DBusException) and \
-                error.get_dbus_name() == DBUS_UNKNOWN_SERVICE:
-            logger.debug("Network Manager not present")
-            # Assuming since Network Manager is not installed,
-            # the user has connected in some other way
-            self.call_result_cb(ONLINE)
-        else:
-            logger.error("Error contacting NetworkManager: %s" %
-                             str(error))
-            self.call_result_cb(UNKNOWN)
+        # Assuming since Network Manager is not running,
+        # the user has connected in some other way
+        logger.error("Error contacting NetworkManager: %s" %
+                         str(error))
+        self.call_result_cb(ONLINE)
 
     def state_changed(self, state):
         """Called when a signal is emmited by Network Manager."""
@@ -107,7 +100,7 @@ class NetworkManagerState(object):
             nm_proxy.Get(NM_DBUS_INTERFACE, "State",
                          reply_handler=self.got_state,
                          error_handler=self.got_error)
-        except Exception as e:  # pylint: disable=W0703
+        except Exception as e:
             self.got_error(e)
 
 
@@ -123,13 +116,11 @@ def is_machine_connected():
         result = (state == ONLINE)
         d.callback(result)
 
-    # pylint: disable=W0702, W0703
     try:
         network = NetworkManagerState(got_state)
         network.find_online_state()
     except Exception as e:
         logger.exception('is_machine_connected failed with:')
         d.errback(NetworkFailException(e))
-    # pylint: enable=W0702, W0703
 
     return d
