@@ -55,8 +55,8 @@ from ubuntu_sso.networkstate.networkstates import (
     NM_STATE_UNKNOWN,
 )
 
-from ubuntu_sso.networkstate.linux import (is_machine_connected,
-    DBUS_UNKNOWN_SERVICE,
+from ubuntu_sso.networkstate.linux import (
+    is_machine_connected,
     NM_DBUS_INTERFACE,
     NM_DBUS_OBJECTPATH,
 )
@@ -174,7 +174,7 @@ class TestConnection(TestCase):
         self.assertEqual(nms.state_signal.interface,
             "org.freedesktop.NetworkManager")
         self.assertEqual(self.network_changes,
-            [UNKNOWN, ONLINE, OFFLINE, ONLINE])
+            [ONLINE, ONLINE, OFFLINE, ONLINE])
         self.assertFalse(nms.state_signal.removed)
 
     @inlineCallbacks
@@ -213,15 +213,6 @@ class TestConnection(TestCase):
         yield self.assertFailure(is_machine_connected(), NetworkFailException)
 
 
-class TestNmNotAvailableException(Exception):
-
-    """An exception to test unavailability conditions."""
-
-    def get_dbus_name(self):
-        """The real name of the dbus error when NM is not running."""
-        return DBUS_UNKNOWN_SERVICE
-
-
 class NetworkManagerBaseTestCase(MockerTestCase):
     """Base test case for NM state tests."""
 
@@ -251,7 +242,6 @@ class NetworkManagerBaseTestCase(MockerTestCase):
 
         proxymock.Get(ARGS, KWARGS)
         if exc is not None:
-            self.expect(self.dbusmock.exceptions.DBusException)
             self.mocker.result(exc)
         self.mocker.replay()
 
@@ -367,16 +357,15 @@ class NetworkManagerStateErrorsTestCase(NetworkManagerBaseTestCase):
     def mock_except_while_getting_proxy(self, exc):
         """Simulate an exception while getting the DBus proxy object."""
         self.mocker.throw(exc)
-        self.expect(self.dbusmock.exceptions.DBusException)
         self.mocker.result(exc)
         self.mocker.replay()
 
-    def test_nm_not_installed(self):
-        """Check the case when NM is not installed."""
-        self.connect_proxy(TestNmNotAvailableException)
-        self.check_nm_error(self.assertOnline, TestNmNotAvailableException())
+    def test_nm_check_errors(self):
+        """Trying to reach NM fails with some error."""
+        self.connect_proxy(Exception)
+        self.check_nm_error(self.assertOnline, Exception())
 
     def test_dbus_problem(self):
         """Check the case when DBus throws some other exception."""
         self.mock_except_while_getting_proxy(TestException)
-        self.get_nms(self.assertUnknown)
+        self.get_nms(self.assertOnline)
