@@ -45,6 +45,7 @@ from win32com.client import Dispatch
 # pylint: enable=F0401
 
 from ubuntu_sso.networkstate import NetworkFailException
+from ubuntu_sso.networkstate.networkstates import ONLINE, OFFLINE
 from ubuntu_sso.logger import setup_logging
 
 logger = setup_logging("ubuntu_sso.networkstate")
@@ -53,9 +54,6 @@ logger = setup_logging("ubuntu_sso.networkstate")
 # it clear for later developers.
 # pylint: disable=C0103
 
-# Values returned by the callback
-ONLINE, OFFLINE, UNKNOWN = object(), object(), object()
-
 ## from EventSys.h
 PROGID_EventSystem = "EventSystem.EventSystem"
 PROGID_EventSubscription = "EventSystem.EventSubscription"
