@@ -70,11 +70,10 @@ class NetworkDetectionPage(SSOWizardPage):
         self.setButtonText(QtGui.QWizard.CustomButton1, TRY_AGAIN_BUTTON)
         self.setButtonText(QtGui.QWizard.CancelButton,
             CLOSE_AND_SETUP_LATER)
-        self.wizard().setButtonLayout([
-            QtGui.QWizard.Stretch,
-            QtGui.QWizard.CustomButton1,
-            QtGui.QWizard.CancelButton,
-            ])
+        self.wizard().setButtonLayout([QtGui.QWizard.Stretch,
+                                       QtGui.QWizard.CustomButton1,
+                                       QtGui.QWizard.CancelButton,
+                                       ])
 
         try:
             self.wizard().customButtonClicked.disconnect()
