@@ -115,15 +115,13 @@ class ProxyCredsDialog(QDialog):
         password = compat.text_type(
                         self.ui.password_entry.text()).encode('utf8')
         creds = dict(username=username, password=password)
-        # pylint: disable=W0703, W0612
         try:
             logger.debug('Save credentials as for domain %s.', self.domain)
             yield self.keyring.set_credentials(self.domain, creds)
         except Exception as e:
-            logger.exception('Could not set credentials:')
+            logger.exception('Could not set credentials: %s', e)
             self.done(EXCEPTION_RAISED)
         logger.debug('Stored creds')
-        # pylint: disable=W0703, W0612
         self.done(USER_SUCCESS)
 
     def _on_cancel_clicked(self, *args):
@@ -169,15 +167,13 @@ def exit_code(return_code):
 
 def main():
     """Main method used to show the creds dialog."""
-    # Keep ref to avoid core dump, pylint: disable=W0612
-
     if sys.platform == 'win32':
         import qt4reactor
         qt4reactor.install()
         logger.debug('Qt reactor installed.')
 
     app = QApplication(sys.argv)
-    # pylint: enable=W0612
+    app
     args = parse_args()
     win = ProxyCredsDialog(domain=args.domain,
                            retry=args.retry)
@@ -187,11 +183,9 @@ def main():
         win.finished.connect(exit_code)
 
         logger.debug('Starting reactor')
-        # pylint: disable=E1101
         from twisted.internet import reactor
         logger.debug('QApp is %s', reactor.qApp)
         reactor.run()
-        # pylint: enable=E1101
     else:
         return_code = win.exec_()
         sys.exit(return_code)
