@@ -42,6 +42,7 @@ from ubuntu_sso.tests import (
     TC_URL,
     WINDOW_ID,
 )
+from ubuntu_sso.utils import compat
 
 KWARGS = dict(app_name=APP_NAME, help_text=HELP_TEXT, ping_url=PING_URL,
               policy_url=POLICY_URL, tc_url=TC_URL, window_id=WINDOW_ID)
@@ -498,10 +499,10 @@ class BaseTestCase(TestCase):
         label = QtGui.QLabel()
         maybe_elide_text(label, expected, max_width)
 
-        self.assertEqual(TITLE_STYLE % unicode(label.text()),
-                         unicode(title_label.text()))
-        self.assertEqual(unicode(label.toolTip()),
-                         unicode(title_label.toolTip()))
+        self.assertEqual(TITLE_STYLE % compat.text_type(label.text()),
+                         compat.text_type(title_label.text()))
+        self.assertEqual(compat.text_type(label.toolTip()),
+                         compat.text_type(title_label.toolTip()))
         self.assertTrue(title_label.isVisible())
 
     def assert_subtitle_correct(self, subtitle_label, expected, max_width):
@@ -509,9 +510,10 @@ class BaseTestCase(TestCase):
         label = QtGui.QLabel()
         maybe_elide_text(label, expected, max_width)
 
-        self.assertEqual(unicode(label.text()), unicode(subtitle_label.text()))
-        self.assertEqual(unicode(label.toolTip()),
-                         unicode(subtitle_label.toolTip()))
+        self.assertEqual(compat.text_type(label.text()),
+                         compat.text_type(subtitle_label.text()))
+        self.assertEqual(compat.text_type(label.toolTip()),
+                         compat.text_type(subtitle_label.toolTip()))
         self.assertTrue(subtitle_label.isVisible())
 
     def assert_error_correct(self, error_label, expected, max_width):
@@ -519,10 +521,10 @@ class BaseTestCase(TestCase):
         label = QtGui.QLabel()
         maybe_elide_text(label, expected, max_width)
 
-        self.assertEqual(ERROR_STYLE % unicode(label.text()),
-                         unicode(error_label.text()))
-        self.assertEqual(unicode(label.toolTip()),
-                         unicode(error_label.toolTip()))
+        self.assertEqual(ERROR_STYLE % compat.text_type(label.text()),
+                         compat.text_type(error_label.text()))
+        self.assertEqual(compat.text_type(label.toolTip()),
+                         compat.text_type(error_label.toolTip()))
         self.assertTrue(error_label.isVisible())
 
     def get_pixmap_data(self, pixmap):
