@@ -272,8 +272,6 @@ class SetupAccountTestCase(PageBaseTestCase):
 
     def test_connect_ui_2(self):
         """Test more connections from connect_ui"""
-
-        #
         self.assertEqual(self.ui.ui.captcha_solution_edit.receivers(
             QtCore.SIGNAL("textEdited(const QString&)")), 1)
         self.assertEqual(self.ui.terms_checkbox.receivers(
@@ -378,8 +376,8 @@ class SetupAccountTestCase(PageBaseTestCase):
     def test_show_event(self):
         """Check that show_event works when set_up_button is none."""
         self.assertEqual(self.ui.set_up_button, None)
-        self.ui.showEvent(QtGui.QShowEvent())
-        self.ui.hideEvent(QtGui.QHideEvent())
+        self.ui.show()
+        self.addCleanup(self.ui.hide)
 
     def test_on_captcha_generated(self):
         """Check that the captcha image is handled correctly."""
