@@ -40,7 +40,7 @@ from twisted.trial import unittest
 
 from ubuntu_sso.keyring import get_token_name
 
-APP_NAME = 'I ♥ Ubuntu'
+APP_NAME = 'Ubuntu One'
 CAPTCHA_ID = 'test ñiña'
 CAPTCHA_PATH = os.path.abspath(os.path.join(os.curdir, 'ubuntu_sso', 'tests',
                                             'files', 'captcha.png'))
