@@ -31,10 +31,17 @@
 # files in the program, then also delete it here.
 """Tests for the SSO account code."""
 
+from __future__ import unicode_literals
+
 import os
-import urllib2
+
+# pylint: disable=W0621,F0401,E0611
+try:
+    import urllib.request as url_lib
+except ImportError:
+    import urllib2 as url_lib
+# pylint: enable=W0621,F0401,E0611
 
-from oauth import oauth
 from twisted.trial.unittest import TestCase
 from twisted.internet import defer
 
@@ -51,7 +58,6 @@ from ubuntu_sso.account import (
     ResetPasswordTokenError,
     SSO_STATUS_OK,
     SSO_STATUS_ERROR,
-    TimestampedAuthorizer,
 )
 from ubuntu_sso.tests import (
     APP_NAME,
@@ -66,12 +72,13 @@ from ubuntu_sso.tests import (
     TOKEN,
     TOKEN_NAME,
 )
+from ubuntu_sso.utils import compat
 
 
 CANT_RESET_PASSWORD_CONTENT = "CanNotResetPassowrdError: " \
                               "Can't reset password for this account"
 RESET_TOKEN_INVALID_CONTENT = "AuthToken matching query does not exist."
-EMAIL_ALREADY_REGISTERED = u'a@example.com'
+EMAIL_ALREADY_REGISTERED = 'a@example.com'
 STATUS_UNKNOWN = {'status': 'yadda-yadda'}
 STATUS_ERROR = {'status': SSO_STATUS_ERROR,
                 'errors': {'something': ['Bla', 'Ble']}}
@@ -81,7 +88,7 @@ STATUS_EMAIL_ERROR = {'errors': {'email_token': ['Error1', 'Error2']}}
 STATUS_EMAIL_OK = {'email': EMAIL}
 
 FAKE_NEW_CAPTCHA = {
-    'image_url': "file://" + unicode(CAPTCHA_PATH),
+    'image_url': "file://" + compat.text_type(CAPTCHA_PATH),
     'captcha_id': CAPTCHA_ID,
 }
 
@@ -179,17 +186,17 @@ class FakeRestfulClient(object):
 
     def fake_accounts_me(self):
         """Fake the 'me' information."""
-        return {u'username': u'Wh46bKY',
-                u'preferred_email': self.preferred_email,
-                u'displayname': u'',
-                u'unverified_emails': [u'aaaaaa@example.com'],
-                u'verified_emails': [],
-                u'openid_identifier': u'Wh46bKY'}
+        return {'username': 'Wh46bKY',
+                'preferred_email': self.preferred_email,
+                'displayname': '',
+                'unverified_emails': ['aaaaaa@example.com'],
+                'verified_emails': [],
+                'openid_identifier': 'Wh46bKY'}
 
     def check_all_kwargs_unicode(self, **kwargs):
         """Check that the values of all keyword arguments are unicode."""
         for (key, value) in kwargs.items():
-            if isinstance(value, str):
+            if isinstance(value, compat.binary_type):
                 raise AssertionError("Error: kwarg '%s' is non-unicode." % key)
 
     def restcall(self, method_name, **kwargs):
@@ -203,36 +210,6 @@ class FakeRestfulClient(object):
             return defer.fail(e)
 
 
-class TimestampedAuthorizerTestCase(TestCase):
-    """Test suite for the TimestampedAuthorizer."""
-
-    def test_authorize_request_includes_timestamp(self):
-        """The authorizeRequest method includes the timestamp."""
-        fromcandt_call = []
-        fake_uri = "http://protocultura.net"
-        fake_timestamp = 1234
-        get_fake_timestamp = lambda: fake_timestamp
-        original_oauthrequest = oauth.OAuthRequest
-
-        class FakeOAuthRequest(oauth.OAuthRequest):
-            """A Fake OAuthRequest class."""
-
-            @staticmethod
-            def from_consumer_and_token(*args, **kwargs):
-                """A fake from_consumer_and_token."""
-                fromcandt_call.append((args, kwargs))
-                builder = original_oauthrequest.from_consumer_and_token
-                return builder(*args, **kwargs)
-
-        self.patch(oauth, "OAuthRequest", FakeOAuthRequest)
-
-        authorizer = TimestampedAuthorizer(get_fake_timestamp, "ubuntuone")
-        authorizer.authorizeRequest(fake_uri, "POST", None, {})
-        call_kwargs = fromcandt_call[0][1]
-        parameters = call_kwargs["parameters"]
-        self.assertEqual(parameters["oauth_timestamp"], fake_timestamp)
-
-
 class AccountTestCase(TestCase):
     """Test suite for the SSO login processor."""
 
@@ -247,7 +224,7 @@ class AccountTestCase(TestCase):
             self.addCleanup(f.close)
             return f
 
-        self.patch(urllib2, 'urlopen', fake_urlopen)  # fd to the path
+        self.patch(url_lib, 'urlopen', fake_urlopen)  # fd to the path
         self.processor = Account()
         self.register_kwargs = dict(email=EMAIL, password=PASSWORD,
                                     displayname=NAME,
@@ -262,7 +239,7 @@ class AccountTestCase(TestCase):
 
     def verify_frc_shutdown(self):
         """Verify that the FakeRestfulClient was stopped."""
-        assert self.frc.started == False, "Restfulclient must be shut down."
+        assert self.frc.started is False, "Restfulclient must be shut down."
 
     @defer.inlineCallbacks
     def test_generate_captcha(self):
@@ -286,27 +263,27 @@ class AccountTestCase(TestCase):
     @defer.inlineCallbacks
     def test_register_user_checks_valid_email(self):
         """Email is validated."""
-        self.register_kwargs['email'] = u'notavalidemail'
+        self.register_kwargs['email'] = 'notavalidemail'
         d = self.processor.register_user(**self.register_kwargs)
         yield self.assertFailure(d, InvalidEmailError)
 
     @defer.inlineCallbacks
     def test_register_user_checks_valid_password(self):
         """Password is validated."""
-        self.register_kwargs['password'] = u''
+        self.register_kwargs['password'] = ''
         d = self.processor.register_user(**self.register_kwargs)
         yield self.assertFailure(d, InvalidPasswordError)
 
         # 7 chars, one less than expected
-        self.register_kwargs['password'] = u'tesT3it'
+        self.register_kwargs['password'] = 'tesT3it'
         d = self.processor.register_user(**self.register_kwargs)
         yield self.assertFailure(d, InvalidPasswordError)
 
-        self.register_kwargs['password'] = u'test3it!'  # no upper case
+        self.register_kwargs['password'] = 'test3it!'  # no upper case
         d = self.processor.register_user(**self.register_kwargs)
         yield self.assertFailure(d, InvalidPasswordError)
 
-        self.register_kwargs['password'] = u'testIt!!'  # no number
+        self.register_kwargs['password'] = 'testIt!!'  # no number
         d = self.processor.register_user(**self.register_kwargs)
         yield self.assertFailure(d, InvalidPasswordError)
 
