@@ -50,7 +50,6 @@ from ubuntu_sso.credentials import (
 from ubuntu_sso.tests import (
     APP_NAME,
     EMAIL,
-    GTK_GUI_EXE,
     HELP_TEXT,
     PASSWORD,
     PING_URL,
@@ -122,8 +121,11 @@ class BasicTestCase(TestCase):
         self.memento = MementoHandler()
         self.memento.setLevel(logging.DEBUG)
         credentials.logger.addHandler(self.memento)
+        self.addCleanup(credentials.logger.removeHandler, self.memento)
 
-        self.patch(credentials, 'get_bin_dir', lambda: self.bin_dir)
+        self.patch(credentials, 'get_bin_cmd',
+                   lambda x: [os.path.join(self.bin_dir,
+                                          KWARGS[UI_EXECUTABLE_KEY])])
 
     def _set_called(self, *args, **kwargs):
         """Set _called to True."""
@@ -147,7 +149,7 @@ class CredentialsCallbacksTestCase(CredentialsTestCase):
 
     def test_creation_parameters_are_stored(self):
         """Creation parameters are stored."""
-        for key, value in KWARGS.iteritems():
+        for key, value in KWARGS.items():
             self.assertEqual(getattr(self.obj, key), value)
 
     def test_tc_url_defaults_to_none(self):
@@ -190,13 +192,14 @@ class CredentialsCallbacksTestCase(CredentialsTestCase):
 
         self.assertEqual(getattr(self.obj, POLICY_URL_KEY), None)
 
-    def test_ui_executable_defaults_to_gtk(self):
-        """The ui class defaults to gtk."""
+    def test_ui_executable_default(self):
+        """The ui class defaults to Qt."""
         newkw = KWARGS.copy()
         newkw.pop(UI_EXECUTABLE_KEY)
         self.obj = credentials.Credentials(**newkw)
 
-        self.assertEqual(getattr(self.obj, UI_EXECUTABLE_KEY), GTK_GUI_EXE)
+        self.assertEqual(getattr(self.obj, UI_EXECUTABLE_KEY),
+                         credentials.UI_EXECUTABLE_QT)
 
 
 class FindCredentialsTestCase(CredentialsTestCase):
@@ -350,10 +353,6 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_SUCCESS
 
-        # patch os.path.exists so it returns True for the faked exe_path
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path == self.exe_path)
-
         result = yield self.method_call(**self.kwargs)
         self.assertEqual(result, TOKEN)
 
@@ -362,34 +361,21 @@ class RegisterTestCase(CredentialsTestCase):
         self.assertEqual(self.inner_args, args)
 
     @defer.inlineCallbacks
-    def test_ui_executable_falls_back_to_gtk(self):
-        """The executable falls back to the GTK+ UI if given does not exist."""
+    def test_ui_executable_fall_back(self):
+        """The executable falls back to the Qt UI if given does not exist."""
         self.patch(credentials.Keyring, 'get_credentials',
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_SUCCESS
 
-        assert not os.path.exists(self.exe_path)
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path.endswith(credentials.UI_EXECUTABLE_GTK))
+        def get_bin_cmd_raises_if_not_qt(path):
+            """Simulates nonexistence of exes that aren't qt."""
+            if not path.endswith(credentials.UI_EXECUTABLE_QT):
+                raise OSError()
+            return [os.path.join(self.bin_dir,
+                                credentials.UI_EXECUTABLE_QT)]
 
-        result = yield self.method_call(**self.kwargs)
-        self.assertEqual(result, TOKEN)
-
-        # the ui was opened and proper params were passed
-        args = yield self.deferred
-        self.inner_args[0] = os.path.join(self.bin_dir,
-                                          credentials.UI_EXECUTABLE_GTK)
-        self.assertEqual(self.inner_args, args)
-
-    @defer.inlineCallbacks
-    def test_ui_executable_uses_qt_ui_if_gtk_not_available(self):
-        """The executable loads the QT UI if the GTK+ does not exist."""
-        self.patch(credentials.Keyring, 'get_credentials',
-                   lambda kr, app: defer.succeed(None))
-        self._next_inner_result = credentials.USER_SUCCESS
-
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path.endswith(credentials.UI_EXECUTABLE_QT))
+        self.patch(credentials, 'get_bin_cmd',
+                   get_bin_cmd_raises_if_not_qt)
 
         result = yield self.method_call(**self.kwargs)
         self.assertEqual(result, TOKEN)
@@ -405,7 +391,12 @@ class RegisterTestCase(CredentialsTestCase):
         """If no GUI is available, raise GUINotAvailableError."""
         self.patch(credentials.Keyring, 'get_credentials',
                    lambda kr, app: defer.succeed(None))
-        self.patch(credentials.os.path, 'exists', lambda path: False)
+
+        def get_bin_cmd_just_raises(*args, **kwargs):
+            """Workaround for lambda: raise."""
+            raise OSError()
+
+        self.patch(credentials, 'get_bin_cmd', get_bin_cmd_just_raises)
 
         f = self.method_call(**self.kwargs)
         yield self.assertFailure(f, credentials.GUINotAvailableError)
@@ -417,9 +408,6 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_CANCELLATION
 
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path == self.exe_path)
-
         if exc is None:
             exc = credentials.UserCancellationError
         yield self.assertFailure(self.method_call(**self.kwargs), exc)
@@ -431,9 +419,6 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self._next_inner_result = credentials.USER_CANCELLATION * 2  # other
 
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path == self.exe_path)
-
         exc = yield self.assertFailure(self.method_call(**self.kwargs),
                                        credentials.CredentialsError)
         if result is None:
@@ -460,9 +445,6 @@ class RegisterTestCase(CredentialsTestCase):
                    lambda kr, app: defer.succeed(None))
         self.patch_inner(self.fail_inner)
 
-        self.patch(credentials.os.path, 'exists',
-                   lambda path: path == self.exe_path)
-
         yield self.assertFailure(self.method_call(**self.kwargs),
                                  SampleMiscException)
 
@@ -516,10 +498,10 @@ class LoginEmailPasswordTestCase(RegisterTestCase):
         """Make the inner call fail."""
         raise SampleMiscException(kwargs)
 
-    def test_ui_executable_falls_back_to_gtk(self):
+    def test_ui_executable_fall_back(self):
         """This check does not apply for this test case."""
 
-    def test_ui_executable_uses_qt_ui_if_gtk_not_available(self):
+    def test_ui_executable_uses_qt_ui_if_none_available(self):
         """This check does not apply for this test case."""
 
     def test_raises_exception_if_no_ui_available(self):
