@@ -33,6 +33,7 @@ from __future__ import unicode_literals
 import os
 import sys
 
+from dirspec.basedir import load_config_paths
 from dirspec.utils import get_program_path
 
 from twisted.internet import defer
@@ -141,6 +142,30 @@ def get_bin_cmd(program_name):
     return cmd_args
 
 
+def get_cert_dir():
+    """Return directory containing certificate files."""
+
+    if getattr(sys, "frozen", None) is not None:
+        if sys.platform == "win32":
+            ssl_cert_location = list(load_config_paths(
+                    "ubuntuone"))[1]
+        elif sys.platform == "darwin":
+                main_app_dir = "".join(__file__.partition(".app")[:-1])
+                main_app_resources_dir = os.path.join(main_app_dir,
+                                                      "Contents",
+                                                      "Resources")
+                ssl_cert_location = main_app_resources_dir
+    elif any(plat in sys.platform for plat in ("win32", "darwin")):
+        pkg_dir = os.path.dirname(__file__)
+        src_tree_path = os.path.dirname(os.path.dirname(pkg_dir))
+        ssl_cert_location = os.path.join(src_tree_path,
+                                         "data")
+    else:
+        ssl_cert_location = '/etc/ssl/certs'
+
+    return ssl_cert_location
+
+
 @defer.inlineCallbacks
 def ping_url(url, email, credentials):
     """Ping the 'url' with the 'email' attached to it.
