@@ -153,22 +153,3 @@ class QtSpawnProgramTestCase(SpawnProgramTestCase):
         yield d
 
         self.assertNotIn(self.process, qt._processes)
-
-    @defer.inlineCallbacks
-    def test_start_process_win_devel(self):
-        """Test the windows devel case."""
-        calls = []
-        fake_python = r"c:\python99\python.exe"
-        self.patch(runner.qt.sys, "platform", "win98")
-        self.patch(runner.qt.procutils, "which", lambda _: [fake_python])
-        self.patch(subprocess, "call", calls.append)
-        self.patch(self, "args", ["bin/program", "arg1", "arg2"])
-
-        d = defer.Deferred()
-        runner.qt.spawn_program(self.args,
-            reply_handler=d.callback, error_handler=lambda **kw: d.errback(kw))
-        yield d
-
-        cmdline = calls[0]
-        self.assertEqual(cmdline[0], fake_python,
-                        "python.exe is added to the command line.")
