@@ -30,7 +30,8 @@
 
 import subprocess
 
-from twisted.internet import defer, protocol, reactor
+from twisted.internet import defer, error, protocol
+from twisted.internet.endpoints import clientFromString
 
 LOCALHOST = "127.0.0.1"
 DELAY_BETWEEN_CHECKS = 0.1
@@ -42,6 +43,7 @@ NUMBER_OF_CHECKS = 600
 
 def async_sleep(delay):
     """Fire the returned deferred after some specified delay."""
+    from twisted.internet import reactor
     d = defer.Deferred()
     # pylint: disable=E1101
     reactor.callLater(delay, d.callback, None)
@@ -67,6 +69,8 @@ class NullProtocol(protocol.Protocol):
 class PortDetectFactory(protocol.ClientFactory):
     """Will detect if something is listening in a given port."""
 
+    protocol = NullProtocol
+
     def __init__(self):
         """Initialize this instance."""
         self.d = defer.Deferred()
@@ -77,17 +81,20 @@ class PortDetectFactory(protocol.ClientFactory):
 
     def buildProtocol(self, addr):
         """Connected."""
+        p = protocol.ClientFactory.buildProtocol(self, addr)
         if not self.d.called:
             self.d.callback(True)
-        return NullProtocol()
+        return p
 
     def clientConnectionLost(self, connector, reason):
         """The connection was lost."""
+        protocol.ClientFactory.clientConnectionLost(self, connector, reason)
         if not self.d.called:
             self.d.callback(False)
 
     def clientConnectionFailed(self, connector, reason):
         """The connection failed."""
+        protocol.ClientFactory.clientConnectionFailed(self, connector, reason)
         if not self.d.called:
             self.d.callback(False)
 
@@ -95,11 +102,11 @@ class PortDetectFactory(protocol.ClientFactory):
 class ActivationConfig(object):
     """The configuration for tcp activation."""
 
-    def __init__(self, service_name, command_line, port):
+    def __init__(self, service_name, command_line, description):
         """Initialize this instance."""
         self.service_name = service_name
         self.command_line = command_line
-        self.port = port
+        self.description = description
 
 
 class ActivationDetector(object):
@@ -112,9 +119,13 @@ class ActivationDetector(object):
     @defer.inlineCallbacks
     def is_already_running(self):
         """Check if the instance is already running."""
+        from twisted.internet import reactor
         factory = PortDetectFactory()
-        # pylint: disable=E1101
-        reactor.connectTCP(LOCALHOST, self.config.port, factory)
+        client = clientFromString(reactor, self.config.description.client)
+        try:
+            yield client.connect(factory)
+        except error.ConnectError:
+            defer.returnValue(False)
         result = yield factory.is_listening()
         defer.returnValue(result)
 
@@ -128,7 +139,7 @@ class ActivationClient(ActivationDetector):
     @defer.inlineCallbacks
     def _wait_server_active(self):
         """Wait till the server is active."""
-        for _ in xrange(NUMBER_OF_CHECKS):
+        for _ in range(NUMBER_OF_CHECKS):
             is_running = yield self.is_already_running()
             if is_running:
                 defer.returnValue(None)
@@ -143,20 +154,20 @@ class ActivationClient(ActivationDetector):
         subprocess.Popen(self.config.command_line, close_fds=True)
 
     @defer.inlineCallbacks
-    def _do_get_active_port(self):
-        """Get the port for the running instance, starting it if needed."""
+    def _do_get_active_description(self):
+        """Get the details for the running instance, starting it if needed."""
         is_running = yield self.is_already_running()
         if not is_running:
             self._spawn_server()
             yield self._wait_server_active()
-        defer.returnValue(self.config.port)
+        defer.returnValue(self.config.description.client)
 
     @defer.inlineCallbacks
-    def get_active_port(self):
-        """Serialize the requests to _do_get_active_port."""
+    def get_active_client_description(self):
+        """Serialize the requests to _do_get_active_description."""
         yield self.lock.acquire()
         try:
-            result = yield self._do_get_active_port()
+            result = yield self._do_get_active_description()
             defer.returnValue(result)
         finally:
             self.lock.release()
@@ -166,9 +177,9 @@ class ActivationInstance(ActivationDetector):
     """A tcp activation server instance."""
 
     @defer.inlineCallbacks
-    def get_port(self):
+    def get_server_description(self):
         """Get the port to run this service or fail if already started."""
         is_running = yield self.is_already_running()
         if is_running:
             raise AlreadyStartedError()
-        defer.returnValue(self.config.port)
+        defer.returnValue(self.config.description.server)
