@@ -38,6 +38,11 @@ from twisted.spread.pb import (
     NoSuchMethod,
 )
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipIfOS
+from ubuntuone.devtools.testcases.txsocketserver import (
+    TidyUnixServer,
+    TCPPbServerTestCase,
+)
 
 from ubuntu_sso.tests import TestCase
 from ubuntu_sso.utils import ipc
@@ -45,7 +50,8 @@ from ubuntu_sso.utils import ipc
 
 TEST_SERVICE = 'foo-service'
 TEST_CMDLINE = 'foo.bin'
-TEST_PORT = 40404
+TEST_SERVER_DESCRIPTION = 'tcp:40404:interface=127.0.0.1'
+TEST_CLIENT_DESCRIPTION = 'tcp:host=127.0.0.1:port=40404'
 
 
 class RandomException(Exception):
@@ -59,15 +65,30 @@ class FakeActivationClient(object):
         """Initialize this fake instance."""
         self.config = config
 
-    def get_active_port(self):
-        """Return the port where the pb server is running."""
-        return defer.succeed(self.config.port)
+    def get_active_client_description(self):
+        """Return the description where the pb server is running."""
+        return defer.succeed(self.config.description.client)
 
 
-class FakeActivationInstance(FakeActivationClient):
+class FakeActivationInstance(object):
     """A fake ActivationInstance."""
 
-    get_port = FakeActivationClient.get_active_port
+    def __init__(self, config):
+        """Initialize the fake instance."""
+        self.config = config
+
+    def get_server_description(self):
+        """Return the description where the pb server is running."""
+        return defer.succeed(self.config.description.server)
+
+
+class FakeDescriptionFactory(object):
+    """A fake description factory."""
+
+    def __init__(self, server_description, client_description):
+        """Create a new instace."""
+        self.server = server_description
+        self.client = client_description
 
 
 # Invalid name "callRemote", etc.
@@ -79,20 +100,33 @@ class FakeReactor(object):
 
     def __init__(self):
         """Initialize this faker."""
-        self.connection_class = namedtuple("Connection", "host port factory")
+        self.connection_class = namedtuple("Connection",
+                                         "host port factory backlog")
         self.connections = []
 
-    def connectTCP(self, host, port, factory):
+    def connectTCP(self, host, port, factory, timeout=None, bindAddress=None):
         """Store the connected factory."""
-        connection = self.connection_class(host, port, factory)
+        connection = self.connection_class(host, port, factory, None)
         self.connections.append(connection)
 
-    def listenTCP(self, port, factory, interface):
+    def listenTCP(self, port, factory, interface=None, backlog=None):
         """Store the listenning factory."""
-        connection = self.connection_class(interface, port, factory)
+        connection = self.connection_class(interface, port, factory, backlog)
         self.connections.append(connection)
 
 
+class FakeTCP4ClientEndpoint(object):
+    """A fake tcp4 client."""
+
+    def __init__(self, protocol):
+        """Create a new instance."""
+        self.protocol = protocol
+
+    def connect(self, *args, **kwargs):
+        """Return the client."""
+        return defer.succeed(self.protocol)
+
+
 class FakeRemoteClient(object):
     """A fake RemoteClient."""
 
@@ -165,7 +199,7 @@ class DummyService(ipc.BaseService):
 
     services = {'dummy': DummyRemoteService}
     name = 'Dummy Service'
-    port = TEST_PORT
+    description = TEST_CLIENT_DESCRIPTION
     cmdline = 'yadda yo'
 
 
@@ -181,11 +215,20 @@ class DummyClient(ipc.BaseClient):
 
     clients = {'dummy': DummyRemoteClient}
     service_name = DummyService.name
-    service_port = DummyService.port
+    service_port = TEST_SERVER_DESCRIPTION
     service_cmdline = DummyService.cmdline
 
 
-class BaseIPCTestCase(TestCase):
+class DummyDescription(object):
+    """Return the descriptions accordingly."""
+
+    def __init__(self, client, server):
+        """Create a new instance."""
+        self.client = client
+        self.server = server
+
+
+class BaseIPCTestCase(TCPPbServerTestCase, TestCase):
     """Set the ipc to a random port for this instance."""
 
     timeout = 5
@@ -201,20 +244,45 @@ class BaseIPCTestCase(TestCase):
 
     @defer.inlineCallbacks
     def setUp(self):
+        # pylint complains about callables
+        # pylint: disable=E1102
         yield super(BaseIPCTestCase, self).setUp()
 
         self.service = None
         self.client = None
 
         if self.service_class is not None:
-            # pylint: disable=E1102
-            self.service = self.service_class()
-            yield self.service.start()
-            self.addCleanup(self.service.shutdown)
 
+            self.service = self.service_class()
             self.client = self.client_class()
+
+            # patch server connection and client connection to ensure that
+            # we have clean connections
+
+            @defer.inlineCallbacks
+            def server_listen(server_factory, service_name, activation_cmd,
+                              description, reactor=None):
+                """Connect to the local running service."""
+                yield self.listen_server(self.service)
+                defer.returnValue(self.listener)
+
+            self.patch(ipc, 'server_listen', server_listen)
+
+            @defer.inlineCallbacks
+            def client_connect(client_factory, service_name,
+                               activation_cmdline, description, reactor=None):
+                """Connect the local running client."""
+                yield self.connect_client()
+                self.client.factory = self.client_factory
+                defer.returnValue(self.connector)
+
+            self.patch(ipc, 'client_connect', client_connect)
+
+            # pylint: disable=E1102
+            yield self.service.start()
             yield self.client.connect()
-            self.addCleanup(self.client.disconnect)
+
+        # pylint: enable=E1102
 
     @property
     def remote_service(self):
@@ -293,14 +361,15 @@ class BaseIPCTestCase(TestCase):
         """
         for signal_name, args, kwargs in self.signal_mapping:
             self.assert_remote_signal(signal_name, *args, **kwargs)
+# pylint: enable=E1102
 
 
-class ListenConnectTestCase(BaseIPCTestCase):
+class TCPListenConnectTestCase(BaseIPCTestCase):
     """Test suite for the server_listen and client_connect methods."""
 
     @defer.inlineCallbacks
     def setUp(self):
-        yield super(ListenConnectTestCase, self).setUp()
+        yield super(TCPListenConnectTestCase, self).setUp()
         self.fake_reactor = FakeReactor()
 
     @defer.inlineCallbacks
@@ -308,35 +377,60 @@ class ListenConnectTestCase(BaseIPCTestCase):
         """Test the server_listen function."""
         self.patch(ipc, "ActivationInstance", FakeActivationInstance)
 
+        description_factory = FakeDescriptionFactory(TEST_SERVER_DESCRIPTION,
+                                                     TEST_CLIENT_DESCRIPTION)
+
         fake_factory = object()
         yield ipc.server_listen(fake_factory, TEST_SERVICE,
-                                TEST_CMDLINE, TEST_PORT,
+                                TEST_CMDLINE, description_factory,
                                 reactor=self.fake_reactor)
 
         self.assertEqual(len(self.fake_reactor.connections), 1)
         conn = self.fake_reactor.connections[0]
-        self.assertEqual(conn.port, TEST_PORT)
         self.assertEqual(conn.factory, fake_factory)
         self.assertEqual(conn.host, ipc.LOCALHOST)
 
     @defer.inlineCallbacks
     def test_client_connect(self):
         """Test the client_connect function."""
+        called = []
         self.patch(ipc, "ActivationClient", FakeActivationClient)
 
+        protocol = 'protocol'
+        client = FakeTCP4ClientEndpoint(protocol)
+
+        def client_from_string(reactor, description):
+            """Create a client from the given string."""
+            called.append(('clientFromString', reactor, description))
+            return client
+
+        self.patch(ipc.endpoints, 'clientFromString', client_from_string)
+
+        description_factory = FakeDescriptionFactory(TEST_SERVER_DESCRIPTION,
+                                                     TEST_CLIENT_DESCRIPTION)
+
         fake_factory = object()
-        yield ipc.client_connect(fake_factory, TEST_SERVICE,
-                                 TEST_CMDLINE, TEST_PORT,
-                                 reactor=self.fake_reactor)
+        returned_protocol = yield ipc.client_connect(fake_factory,
+                                              TEST_SERVICE,
+                                              TEST_CMDLINE,
+                                              description_factory,
+                                              reactor=self.fake_reactor)
 
-        self.assertEqual(len(self.fake_reactor.connections), 1)
-        conn = self.fake_reactor.connections[0]
-        self.assertEqual(conn.port, TEST_PORT)
-        self.assertEqual(conn.factory, fake_factory)
-        self.assertEqual(conn.host, ipc.LOCALHOST)
+        self.assertIn(('clientFromString', self.fake_reactor,
+                          description_factory.client), called)
+        self.assertEqual(protocol, returned_protocol)
 
 
-class DummyClientTestCase(BaseIPCTestCase):
+@skipIfOS('win32', 'Unix domain sockets not supported on windows.')
+class DomainListenConnectTestCase(TCPListenConnectTestCase):
+    """Test suite for the server_listen and client_connect methods."""
+
+    def get_server(self):
+        """Return the server to be used to run the tests."""
+        return TidyUnixServer()
+
+
+class TCPDummyClientTestCase(BaseIPCTestCase):
     """Test the status client class."""
 
     client_class = DummyClient
@@ -395,6 +489,15 @@ class DummyClientTestCase(BaseIPCTestCase):
             self.assertEqual(0, actual)
 
 
+@skipIfOS('win32', 'Unix domain sockets not supported on windows.')
+class DomainDummyClientTestCase(TCPDummyClientTestCase):
+    """Test the status client class."""
+
+    def get_server(self):
+        """Return the server to be used to run the tests."""
+        return TidyUnixServer()
+
+
 class RemoteMetaTestCase(TestCase):
     """Tests for the RemoteMeta metaclass."""
 
@@ -402,16 +505,16 @@ class RemoteMetaTestCase(TestCase):
         """The remote_calls are renamed."""
         test_token = object()
 
-        class TestClass(object):
+        # pylint: disable=W0232
+        class TestClass(ipc.meta_base(ipc.RemoteMeta)):
             """A class for testing."""
 
-            __metaclass__ = ipc.RemoteMeta
-
             remote_calls = ['test_method']
 
             def test_method(self):
                 """Fake call."""
                 return test_token
+        # pylint: enable=W0232
 
         tc = TestClass()
         self.assertEquals(tc.test_method(), test_token)
@@ -516,3 +619,80 @@ class SignalBroadcasterTestCase(TestCase):
             fake_remote_client.random_exception,
         )
         self.assertTrue(self.memento.check_warning(*expected))
+
+
+class FakeRootObject(object):
+    """A fake root object."""
+
+    def __init__(self, called, remote_obj):
+        """Create a new instance."""
+        self.called = called
+        self.remote_obj = remote_obj
+
+    # pylint: disable=C0103
+    def callRemote(self, method_name):
+        """A fake call remove method."""
+        self.called.append(method_name)
+        return defer.succeed(self.remote_obj)
+    # pylint: enable=C0103
+
+
+class FakeWorkingRemoteClient(object):
+    """A fake remote client."""
+
+    def __init__(self, called):
+        """Create a new instance."""
+        self.remote = None
+        self.called = called
+
+    def register_to_signals(self):
+        """Register to signals."""
+        self.called.append('register_to_signals')
+        return defer.succeed(True)
+
+
+class ReconnectTestCase(TestCase):
+    """Test the reconnection when sso is dead."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set the different tests."""
+        yield super(ReconnectTestCase, self).setUp()
+        self.called = []
+        self.remote_obj = 'remote'
+        self.root_obj = FakeRootObject(self.called, self.remote_obj)
+
+        def fake_get_root_object():
+            """Fake getting the root object."""
+            self.called.append('getRootObject')
+            return defer.succeed(self.root_obj)
+
+        def fake_client_connect(factory, service_name, cmd, description):
+            """Fake the client connect."""
+            self.called.append('client_connect')
+            self.patch(factory, 'getRootObject', fake_get_root_object)
+            return defer.succeed(True)
+
+        self.patch(ipc, 'client_connect', fake_client_connect)
+
+    @defer.inlineCallbacks
+    def test_reconnect_method(self):
+        """Test the execcution of the reconnect method."""
+        clients = dict(first=FakeWorkingRemoteClient(self.called),
+                       second=FakeWorkingRemoteClient(self.called))
+
+        base_client = ipc.BaseClient()
+        base_client.clients = clients
+        for name, client in clients.items():
+            setattr(base_client, name, client)
+
+        yield base_client.reconnect()
+        # assert that we did call the correct methods
+        self.assertIn('client_connect', self.called)
+        self.assertIn('getRootObject', self.called)
+
+        for name in clients:
+            self.assertIn('get_%s' % name, self.called)
+
+        self.assertEqual(len(clients),
+                self.called.count('register_to_signals'))
