@@ -31,7 +31,6 @@
 from __future__ import unicode_literals
 
 import sys
-from io import StringIO
 
 from twisted.trial.unittest import TestCase
 
@@ -82,22 +81,6 @@ class ParseArgsTestCase(TestCase):
         # Access to a protected member, pylint: disable=W0212
         self.assertEqual(expected, dict(result._get_kwargs()))
 
-    def test_parse_args_app_name_is_required(self):
-        """If no app_name, show help and exit."""
-        called = []
-        stderr = StringIO()
-        self.addCleanup(stderr.close)
-
-        self.patch(sys, 'argv', [PROGRAM])
-        self.patch(sys, 'exit', called.append)
-        self.patch(sys, 'stderr', stderr)
-
-        main.parse_args()
-
-        self.assertEqual(called, [2])
-        self.assertIn('usage: %s' % PROGRAM, stderr.getvalue())
-        self.assertIn('app_name is required', stderr.getvalue())
-
     def test_parse_args_defaults(self):
         """The args are correctly set when using defaults."""
         self.assert_parse_args_custom_field()
