@@ -31,19 +31,10 @@
 
 from __future__ import print_function
 
-# twisted uses a different coding convention
-# pylint: disable=C0103,W0232
-
-# this test module access a few protected members (starting with _)
-# pylint: disable=W0212
-
 import twisted.internet
 from twisted.internet import defer, protocol, task
 from twisted.trial.unittest import TestCase
 
-# pylint: disable=W0611
-from ubuntuone.devtools.testcases import skipIfOS
-# pylint: enable=W0611
 from ubuntuone.devtools.testcases.txsocketserver import (
     ServerTestCase,
     TidyTCPServer,
@@ -216,8 +207,8 @@ class ActivationDetectorTestCase(TestCase):
         """Initialize this test instance."""
         yield super(ActivationDetectorTestCase, self).setUp()
         self.description_factory = FakeDescriptionFactory(
-                                                     self.server_description,
-                                                     self.client_description)
+            self.server_description,
+            self.client_description)
         self.config = ActivationConfig(SAMPLE_SERVICE, SAMPLE_CMDLINE,
                                        self.description_factory)
 
@@ -248,7 +239,6 @@ class ActivationDetectorTestCase(TestCase):
         class TestConnect(object):
             """A fake connection object."""
 
-            # pylint: disable=E0213
             @defer.inlineCallbacks
             def connect(my_self, factory):
                 """A fake connection."""
@@ -258,14 +248,12 @@ class ActivationDetectorTestCase(TestCase):
                 self.patch(factory, 'is_listening',
                         connected_factory.is_listening)
                 defer.returnValue(connected_factory)
-            # pylint: enable=E0213
 
         self.patch(tcpactivation, 'clientFromString',
                 lambda *args: TestConnect())
 
         yield server.listen_server(protocol.ServerFactory)
 
-        # pylint: disable=E1101
         ad = ActivationDetector(self.config)
         result = yield ad.is_already_running()
         self.assertTrue(result, "It should be already running.")
@@ -284,8 +272,8 @@ class ActivationClientTestCase(TestCase):
         """Initialize this test instance."""
         yield super(ActivationClientTestCase, self).setUp()
         self.description_factory = FakeDescriptionFactory(
-                                                     self.server_description,
-                                                     self.client_description)
+            self.server_description,
+            self.client_description)
         self.config = ActivationConfig(SAMPLE_SERVICE, SAMPLE_CMDLINE,
                                        self.description_factory)
 
@@ -379,8 +367,8 @@ class ActivationInstanceTestCase(ServerTestCase):
         """Initialize this test instance."""
         yield super(ActivationInstanceTestCase, self).setUp()
         self.description_factory = FakeDescriptionFactory(
-                                                     self.server_description,
-                                                     self.client_description)
+            self.server_description,
+            self.client_description)
         self.config = ActivationConfig(SAMPLE_SERVICE, SAMPLE_CMDLINE,
                                        self.description_factory)
 
@@ -402,7 +390,6 @@ class ActivationInstanceTestCase(ServerTestCase):
         description = yield ai.get_server_description()
         self.assertEqual(description, self.server_description)
 
-    #pylint:disable=W0201
     @defer.inlineCallbacks
     def test_get_description_fails_if_service_already_started(self):
         """The get_description method fails if service already started."""
@@ -412,7 +399,6 @@ class ActivationInstanceTestCase(ServerTestCase):
         class TestConnect(object):
             """A fake connection object."""
 
-            # pylint: disable=E0213
             @defer.inlineCallbacks
             def connect(my_self, factory):
                 """A fake connection."""
@@ -422,7 +408,6 @@ class ActivationInstanceTestCase(ServerTestCase):
                 self.patch(factory, 'is_listening',
                         connected_factory.is_listening)
                 defer.returnValue(connected_factory)
-            # pylint: enable=E0213
 
         self.patch(tcpactivation, 'clientFromString',
                 lambda *args: TestConnect())
@@ -432,7 +417,6 @@ class ActivationInstanceTestCase(ServerTestCase):
         ai = ActivationInstance(self.config)
         yield self.assertFailure(ai.get_server_description(),
                                  AlreadyStartedError)
-    #pylint:enable=W0201
 
 
 def server_test(config):
@@ -445,7 +429,6 @@ def server_test(config):
 
         # start listening
         f = FakeServerFactory()
-        # pylint: disable=E1101
         reactor.listenTCP(description, f)
 
         # try to get the description again
@@ -454,7 +437,6 @@ def server_test(config):
     def already_started(failure):
         """This instance was already started."""
         print("already started!")
-        # pylint: disable=E1101
         reactor.callLater(3, reactor.stop)
 
     def get_description():
@@ -466,7 +448,6 @@ def server_test(config):
     print("starting the server.")
     ai = ActivationInstance(config)
     get_description()
-    # pylint: disable=E1101
     reactor.run()
 
 
@@ -483,7 +464,6 @@ def client_test(config):
         reactor.stop()
 
     d.addCallback(got_description)
-    # pylint: disable=E1101
     reactor.run()
 
 
