@@ -86,8 +86,8 @@ FORGOTTEN_PASSWORD_SUBTITLE = _('To reset your {app_name} password, enter '
     'your registered email address below. We will send instructions to reset '
     'your password.')
 INVALID_EMAIL = _("Please enter a valid email address")
-GENERIC_BACKEND_ERROR = _('There was a problem accessing the Ubuntu Single'
-                          ' Sign On backend.')
+GENERIC_BACKEND_ERROR = _('There was a problem accessing the Ubuntu'
+                          ' One backend.')
 JOIN_HEADER_LABEL = _('Create %(app_name)s account')
 LOADING = _('Loading...')
 LOADING_OVERLAY = _('Getting information, please wait...')
@@ -187,8 +187,8 @@ TRY_AGAIN_BUTTON = _('Try again')
 UNKNOWN_ERROR = _('There was an error when trying to complete the '
     'process. Please check the information and try again.')
 VERIFICATION_CODE = _('Verification code')
-VERIFY_EMAIL_CONTENT = _('Check %(email)s for an email from Ubuntu Single '
-    'Sign On. This message contains a verification code. Enter the code in '
+VERIFY_EMAIL_CONTENT = _('Check %(email)s for an email from Ubuntu One. '
+    'This message contains a verification code. Enter the code in '
     'the field below and click OK to complete creating your %(app_name)s '
     'account.')
 VERIFY_EMAIL_TITLE = _('Enter verification code')
@@ -250,8 +250,8 @@ def is_correct_email(email_address):
 
 def parse_args():
     """Parse sys.argv options."""
-    parser = argparse.ArgumentParser(description='Open the SSO UI.')
-    parser.add_argument('--app_name', required=True,
+    parser = argparse.ArgumentParser(description='Open the Ubuntu One UI.')
+    parser.add_argument('--app_name', default='',
         help='the name of the application to retrieve credentials for')
     parser.add_argument('--ping_url', default='',
         help='a link to be used as the ping url (to notify about new tokens)')
@@ -262,9 +262,9 @@ def parse_args():
     parser.add_argument('--help_text', default='',
         help='extra text that will be shown below the headers')
     parser.add_argument('--window_id', type=int, default=0,
-        help='the window id to be set transient for the SSO dialogs')
+        help='the window id to be set transient for the Ubuntu One dialogs')
     parser.add_argument('--login_only', action='store_true', default=False,
-        help='whether the SSO UI should only offer login or not')
+        help='whether the Ubuntu One UI should only offer login or not')
 
     args = parser.parse_args()
     return args
