@@ -157,9 +157,12 @@ class BaseWebClient(object):
                                               else SIGNATURE_TYPE_AUTH_HEADER),
                               timestamp=str(timestamp))
 
-        url, signed_headers, body = oauth_client.sign(
-            uri, method, parameters if parameters is not None else {},
-            {'Content-Type': 'application/x-www-form-urlencoded'})
+        try:
+            url, signed_headers, body = oauth_client.sign(
+                uri, method, parameters if parameters is not None else {},
+                {'Content-Type': 'application/x-www-form-urlencoded'})
+        except ValueError:
+            url, signed_headers, body = oauth_client.sign(uri, method)
 
         return url, signed_headers, body
 
