@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -30,6 +30,8 @@
 
 from __future__ import unicode_literals
 
+import glob
+import os
 import sys
 from io import StringIO
 
@@ -47,10 +49,12 @@ from PyQt4.QtNetwork import (
     QNetworkReply,
     QNetworkRequest,
     QSslCertificate,
+    QSslConfiguration,
 )
 from twisted.internet import defer
 
 from ubuntu_sso.logger import setup_logging
+from ubuntu_sso.utils import get_cert_dir
 from ubuntu_sso.utils.webclient.common import (
     BaseWebClient,
     HeaderDict,
@@ -62,7 +66,6 @@ from ubuntu_sso.utils.webclient.common import (
 from ubuntu_sso.utils.webclient import gsettings
 
 logger = setup_logging("ubuntu_sso.utils.webclient.qtnetwork")
-PROXY_REQUEST = 'https://one.ubuntu.com'
 
 
 def build_proxy(settings_groups):
@@ -103,6 +106,25 @@ class WebClient(BaseWebClient):
         self.proxy_retry = False
         self.setup_proxy()
 
+        # Apply our local certificates as the SSL configuration to be used
+        # for all QNetworkRequest calls.
+        self.ssl_config = QSslConfiguration.defaultConfiguration()
+        ca_certs = self.ssl_config.caCertificates()
+        try:
+            for path in glob.glob(os.path.join(get_cert_dir(),
+                                               "UbuntuOne*.pem")):
+                with open(path) as f:
+                    cert = QSslCertificate(f.read())
+                    if cert.isValid():
+                        ca_certs.append(cert)
+                    else:
+                        logger.error("invalid certificate: {}".format(path))
+        except (IndexError, IOError) as err:
+            raise WebClientError(
+                    "Unable to configure SSL certificates: {}".format(err))
+
+        self.ssl_config.setCaCertificates(ca_certs)
+
     def _set_proxy(self, proxy):
         """Set the proxy to be used."""
         QNetworkProxy.setApplicationProxy(proxy)
@@ -158,6 +180,7 @@ class WebClient(BaseWebClient):
         """Return a deferred that will be fired with a Response object."""
         uri = self.iri_to_uri(iri)
         request = QNetworkRequest(QUrl(uri))
+        request.setSslConfiguration(self.ssl_config)
         headers = yield self.build_request_headers(uri, method, extra_headers,
                                                    oauth_credentials)
 
