@@ -794,15 +794,6 @@ class OAuthPlainTextTestCase(TestCase):
 
         self.assert_headers_correct(signed_headers)
         self.assertEqual(url, self.sample_url)
-        if params is not None:
-            for param, value in params.items():
-                self.assertIn(param, body)
-                actual = body[param]
-                self.assertEqual(value, actual)
-
-    def test_build_oauth_request_with_params(self):
-        """Check that the oauth request are properly with params."""
-        self.test_build_oauth_request(params=self.sample_params)
 
     @defer.inlineCallbacks
     def test_build_signed_iri(self, params=None):
