@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011-2012 Canonical Ltd.
+# Copyright 2011-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -32,6 +32,7 @@ import time
 
 from twisted.internet import defer
 
+from ubuntu_sso import SSO_UONE_BASE_URL
 from ubuntu_sso.logger import setup_logging
 
 logger = setup_logging("ubuntu_sso.utils.webclient.timestamp")
@@ -43,7 +44,7 @@ class TimestampChecker(object):
 
     CHECKING_INTERVAL = 60 * 60  # in seconds
     ERROR_INTERVAL = 30  # in seconds
-    SERVER_IRI = u"http://one.ubuntu.com/api/time"
+    SERVER_IRI = u"%s/api/time" % SSO_UONE_BASE_URL
 
     def __init__(self, webclient_class):
         """Initialize this instance."""
