@@ -95,6 +95,17 @@ class WebClient(BaseWebClient):
     @defer.inlineCallbacks
     def raw_request(self, method, uri, headers, postdata):
         """Make a raw http request."""
+        # Twisted wants headers as bytes, but because of oauthlib, they might
+        # be unicodes.  Assume utf-8 and revert the encodings.
+        bytes_headers = {}
+        for key, value in headers.items():
+            if isinstance(key, unicode):
+                key = key.encode('utf-8')
+            if isinstance(value, unicode):
+                value = value.encode('utf-8')
+            bytes_headers[key] = value
+        headers = bytes_headers
+
         # delay import, otherwise a default reactor gets installed
         from twisted.web import error
 
